# django-disqus

Export existing comments to and integrate DISQUS_ into your Django_ website.

Features:

- Export django.contrib.comments to DISQUS
- Dump comments from DISQUS into a local JSON file
- Templatetags
- Exporting Comments as WXR

The documentation is available at [http://django-disqus.readthedocs.org/](http://django-disqus.readthedocs.org/).

Fix for Django 1.7
